@@ -8,6 +8,7 @@ from typing import Optional, List
 import addict  # type: ignore
 import argparse
 import asyncio
+import datetime
 import greenstalk  # type: ignore
 import gzip
 import json
@@ -21,11 +22,13 @@ import caep
 import act.scio.logsetup
 import act.scio.config
 
+
 def parse_args() -> argparse.Namespace:
     """Helper setting up the argsparse configuration"""
 
     arg_parser = act.scio.config.parse_args("Scio 2 Analyzer")
     arg_parser.add_argument('--plugins', dest='plugins', type=str)
+    arg_parser.add_argument('--proxy-string', help="Proxy to use webdump upload")
     arg_parser.add_argument('--webdump', dest='webdump', type=str, help="URI to post result data")
 
     return caep.config.handle_args(arg_parser, "scio/etc", "scio.ini", "analyze")
@@ -64,6 +67,13 @@ async def analyze(plugins: List[plugin.BasePlugin],
 
     nlpdata: addict.Dict = get_input(beanstalk_client)
 
+    nlpdata["Analyzed-Date"] = datetime.datetime.now().isoformat()
+
+    # make sure we have a Creation-Date field even though the
+    # document did not contain one. When missing, use current analyzed time.
+    nlpdata["Creation-Date"] = (nlpdata.get("metadata", {})
+                                .get("Creation-Date", nlpdata["Analyzed-Date"]))
+
     staged = []  # for plugins with dependencies
     pipeline = []  # for plugins to be run now
 
@@ -112,6 +122,7 @@ async def async_main() -> None:
 
     if args.plugins:
         try:
+            logging.info("loading plugins from %s", args.plugins)
             plugins += plugin.load_external_plugins(args.plugins)
         except FileNotFoundError:
             logging.warning("Unable to load plugins from %s", args.plugins)
@@ -129,8 +140,10 @@ async def async_main() -> None:
         task = loop.create_task(analyze(plugins, beanstalk_client))
         try:
             await task
-        except LookupError as e:
-            logging.error("Got LookupError. If nltk data is missing, run scio-nltk-download, which should download all nltk data to ~/nltk_data.")
+        except LookupError:
+            logging.error("Got LookupError. If nltk data is missing, "
+                          "run scio-nltk-download, which should download "
+                          "all nltk data to ~/nltk_data.")
             raise
 
         result = task.result()
